/*
 *  Copyright (C) 2000, Sealevel Systems
 *   
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  The author may be contacted via email at support@sealevel.com.  This is 
 *  NOT a technical support address; contact your vendor for help installing
 *  and configuring the software.
 */
#ifndef __SEAIO_DRIVER_H__
#define __SEAIO_DRIVER_H__
#include "seaio_internal_struct.h"
#include "seaio_ioctl.h"
// A debug tag for the compiled binary
#ifdef DEBUG
static char *SEAIO_DRIVER_H __attribute__ ((unused)) =
    "$Id: seaio_driver.h,v 1.2 2005/01/20 20:56:48 dalew Exp $";
#endif

#undef PDEBUG
#ifdef DEBUG
#  ifdef __KERNEL__
#    define PDEBUG(fmt, args...) printk("seaio: "fmt, ## args)
#  else
#    define PDEBUG(fmt, args...) fprintf(stderr, fmt, ## args)
#  endif
#else
#  define PDEBUG(fmt, args...)
#endif

#undef PDEBUGG
#define PDEBUGG(fmt, args...)

#define SEAIO_BUS_TYPE_ISA 0
#define SEAIO_BUS_TYPE_PCI 1
#define SEALEVEL_VENDOR_ID 0x135e
#define OK 1
#define ERR_GEN -1
#define SAMPLE_BUFFERS 10000

#define MIN(a,b) (((a)<(b))?(a):(b))

#define DEBUG_LEVEL_INFO 2
#define DEBUG_LEVEL_ERROR 3

/*
 * The function declarations ...
 */
void seaio_enumerate_devices(void);
pSeaio_Struct seaio_allocate_device(Seaio_Device type);
void seaio_add_device(pSeaio_Struct info);
ssize_t seaio_read(struct file *, char *, size_t, loff_t *);
ssize_t seaio_write(struct file *, const char *, size_t, loff_t *);
void seaio_handle_IOCWRITEPORT(struct file *, unsigned long);
void seaio_handle_IOCREADPORT(struct file *, unsigned long);
int seaio_ioctl(struct inode *, struct file *, unsigned int,
		unsigned long);
int seaio_open(struct inode *, struct file *);
int seaio_release(struct inode *, struct file *);
void seaio_deallocate_devices(pSeaio_Struct info);
void seaio_find_pci_devices(void);
int seaio_allocate_resources(pSeaio_Struct info);
int seaio_deallocate_resources(pSeaio_Struct info);
#ifdef EXPERIMENTAL_INTERRUPT_SUPPORT_ENABLED
static void seaio_interrupt(int irq, void *dev_id, struct pt_regs *regs);
ssize_t seaio_read_buffer(struct file *, char *, size_t, loff_t *);
#endif

/*
 * Our file_operations array (fops)
 */
static struct file_operations seaio_fops = {
	read:		seaio_read,
	write:		seaio_write,
	ioctl:		seaio_ioctl,
	open:		seaio_open,
	release:	seaio_release,
};
#ifdef EXPERIMENTAL_INTERRUPT_SUPPORT_ENABLED
static struct file_operations seaio_buffer_fops = {
	read:		seaio_read_buffer,
	open:		seaio_open,
	release:	seaio_release,
};
#endif

#endif				// __SEAIO_H__
