/*
 *  Copyright (C) 2000, Sealevel Systems
 *   
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  The author may be contacted via email at dalew@sealevel.com.  This is 
 *  NOT a technical support address; contact your vendor for help installing
 *  and configuring the software.
 */

/*******************************************************************
  SeaIoStruct.H
  
  Header file for SeaIo for Windows and Linux.
  Used by SeaIo API library, drivers, and applications.
  
  History:
  
	12-15-97	DJA		Created module 
 *******************************************************************/    
#ifndef __SeaIoStruct_h__
#define __SeaIoStruct_h__
#ifdef LINUX
#include "wincompat.h"
#endif

#define	MAXAICHANNELS					8
#define MAX_AD_RETRIES				5
#define RANGE_0_TO_5					0x00
#define RANGE_MINUS_5_TO_5		0x01
#define RANGE_0_TO_10					0x02
#define RANGE_MINUS_10_TO_10	0x03

/*******************************************************************
  Adapter Information Structure
  Used to store each Port's parameters - returned from the driver 
  to the applications.
 *******************************************************************/  
typedef struct tagADAPTER_INFO 
{
	/*... Future */
	DWORD	dwReserved0;		/* Reserved double words */
	DWORD	dwReserved1;
	DWORD	dwReserved2;
	DWORD	dwReserved3;

	/* ...system resources */
	DWORD	dwStateCapabilities;

	/* ... Adapter setup */
	WORD	wCardNumber;		/* Model of adapter       */
	WORD	wBaseIO;	 		/* Base I/O address								 */

	UCHAR	ucPortInCount;      /* This is a state parameter for 8255 adapters; boot parm for all others */
	UCHAR	ucPortOutCount;		/* This is a state parameter for 8255 adapters; boot parm for all others */
	UCHAR	ucPortCount;		/* The number of I/O addresses this adapter uses */
	UCHAR	ucEnabled;			/* Enabled status */

	WORD	wIRQ;				/* Hardware interrupt - here for future use */

} ADAPTER_INFO, *pADAPTER_INFO;     

/*******************************************************************
  Adapter State Structure
  Used to pass each Port's state parameters between the application
  and the driver.
 *******************************************************************/  
typedef struct tagADAPTER_STATE 
{
	/*... Future */
	DWORD	dwReserved0;		/* Reserved double words */
	DWORD	dwReserved1;

	DWORD	dwInterruptBufferSize; /* Size of the buffer for interrupt-driven operation */
	
	DWORD	dwInterruptControlWord; /* Interrupt Control Word */

	DWORD	dwSampleInterval;	/* Time between samples */

	UCHAR	ucModeCW[9];		/* Mode Control Words 0 - [n-1]  */
   UCHAR ucAIRange[MAXAICHANNELS]; /* Input voltage range for A/D card channels */
   
} ADAPTER_STATE, *pADAPTER_STATE;

/*******************************************************************
  Return Status Codes from API
  These codes are also used to report errors to the API interface.
 *******************************************************************/
enum SEAIO_ERROR_CODES {
    SEAIO_ERROR_NONE,			   /* No Error */
    SEAIO_ERROR_PARAM,		       /* Invalid parameter passed to driver*/
    SEAIO_ERROR_NOT_SUPPORTED,     /* Feature not supported for this driver */
	SEAIO_ERROR_PORT_NOT_OPEN,     /* Invalid port handle in DLL structures */
	SEAIO_ERROR_INVALID_NAME,      /* OS does not recognize device name */
	SEAIO_ERROR_SHARING_VIOLATION, /* Someone else has the device open */
	SEAIO_ERROR_DRIVER_TYPE,
	SEAIO_ERROR_BUFFER,
	SEAIO_ERROR_INCOMPLETE,
	SEAIO_ERROR_GENERAL,
	SEAIO_ERROR_IO_PENDING,
	SEAIO_ERROR_NO_TXBUFFER,
	SEAIO_ERROR_INVALID_DEVICE_REQUEST,   /* Not a valid operation for the target device */
	SEAIO_ERROR_INVALID_HANDLE,
	SEAIO_ERROR_CANCELED,
	SEAIO_ERROR_LAST,
	SEAIO_ERROR_INTERRUPT_BUFFER_OVERFLOW = 128 /* will be or'ed with other error codes on read */
};

/*******************************************************************
  Adapter Capabilites Defines
  These defines are used with dwStateCapabilites member of ADAPTER_INFO 
  to indicate which capabilities are supported by the opened adapter
  and driver.
 *******************************************************************/
#define	PSC_SUPPORTSREADS	0x00000001
#define PSC_SUPPORTSWRITES	0x00000002
#define	PSC_8255			0x00000004

/*******************************************************************
  Interrupt Trigger Defines
  A number of SeaI/O cards (notably the entire 800x series) allow 
  an interrupt to be generated off of Port A, bit 0.  This interrupt
  may be set to trigger on a High Level, Low Level, Rising Edge or 
  Falling Edge.  The values below, OR'ed with the Interrupt Control 
  Word, define the trigger conditions for the interrupt.
  [WARNING]: the level-sensitive triggers are dangerous!  If you 
  set, for instance, a Low level-sensitive interrupt, the interrupt 
  will continue to trigger as long as your signal stays low!  This 
  will lock your computer and probably have undesirable effects on 
  your sampling unless you know exactly what you're doing... 
  [/WARNING]
  Consult your owner's manual for more details on using Interrupt-
  driven sampling in your application.
 *******************************************************************/
#define INTERRUPT_TRIGGER_LEVEL_LOW		0x00000000L
#define INTERRUPT_TRIGGER_LEVEL_HIGH	0x40000000L
#define INTERRUPT_TRIGGER_FALLING_EDGE	0x80000000L
#define INTERRUPT_TRIGGER_RISING_EDGE	0xC0000000L

#endif
