#include "digitalIoDevice.hh"
DigitalIoDevice::DigitalIoDevice(unsigned short int deviceNumber) 
{
	m_openStatus = SeaIo_OpenDevice(deviceNumber, &m_deviceHandle);
}

int DigitalIoDevice::openRelay(unsigned short int relayNumber) 
{
	return SeaIo_RelayOpen(m_deviceHandle, relayNumber);
}

int DigitalIoDevice::closeRelay(unsigned short int relayNumber) 
{
	return SeaIo_RelayClose(m_deviceHandle, relayNumber);
}

int DigitalIoDevice::readPort(unsigned char portNumber, unsigned char &value) 
{
	unsigned long returnLength = 1;
	int status = 0;
	
	status = SeaIo_ReadReg(m_deviceHandle, portNumber, &value, returnLength, &returnLength);

	if (returnLength != 1) {
		status = SEAIO_ERROR_GENERAL;
	}
	
	return status;
}

int DigitalIoDevice::writePort(unsigned char portNumber, unsigned char value) 
{
	return SeaIo_WriteReg(m_deviceHandle, portNumber, value);
}

int DigitalIoDevice::readRelative(unsigned char portNumber, unsigned char &value) 
{
	unsigned char buff[32] = {0};
	unsigned long returnLength = 32;
	int status = 0;
	
	status = SeaIo_GetData(m_deviceHandle, buff, returnLength, &returnLength);
	value = buff[portNumber];

	if (returnLength > 32) {
		status = SEAIO_ERROR_GENERAL;
	}
	
	return status;
}

int DigitalIoDevice::readAllInputs(unsigned char * buffer, unsigned long &bufferLength) 
{
	return SeaIo_GetData(m_deviceHandle, buffer, bufferLength, &bufferLength);
}

int DigitalIoDevice::writeRelative(unsigned char portNumber, unsigned char value) 
{
	unsigned char buff[2] = {0};
	
	buff[0] = portNumber;
	buff[1] = value;

	return SeaIo_PutData(m_deviceHandle, buff);
}

int DigitalIoDevice::setState(ADAPTER_STATE &adapterState) 
{
	return SeaIo_SetAdapterState(m_deviceHandle, &adapterState);
}

int DigitalIoDevice::getState(ADAPTER_STATE &adapterState) 
{
	return SeaIo_GetAdapterState(m_deviceHandle, &adapterState);
}

int DigitalIoDevice::getInfo(ADAPTER_INFO &adapterInfo) 
{
	return SeaIo_GetAdapterInfo(m_deviceHandle, &adapterInfo);
}

int DigitalIoDevice::open(unsigned short int deviceNumber) 
{
	if (m_openStatus == 0) {
		close();
	}

	m_openStatus = SeaIo_OpenDevice(deviceNumber, &m_deviceHandle);
	return m_openStatus;
}

int DigitalIoDevice::close()
{
	m_openStatus = -1;
	return SeaIo_CloseDevice(m_deviceHandle);
}

int DigitalIoDevice::getHandle()
{
	return m_deviceHandle;
}
